@@ -31,11 +31,11 @@ from async_timeout import timeout
 import zmq, zmq.asyncio
 
 from ai.backend.common import msgpack
-from ai.backend.common.asyncio import current_loop
 from ai.backend.common.docker import ImageRef
-from ai.backend.common.enum_extension import StringSetFlag
 from ai.backend.common.types import aobject, KernelId
+from ai.backend.common.utils import current_loop, StringSetFlag
 from ai.backend.common.logging import BraceStyleAdapter
+from .exception import UnsupportedBaseDistroError
 from .resources import KernelResourceSpec
 
 log = BraceStyleAdapter(logging.getLogger(__name__))
@@ -332,6 +332,7 @@ class AbstractCodeRunner(aobject, metaclass=ABCMeta):
         self.finished_at = None
         if not math.isfinite(exec_timeout) or exec_timeout < 0:
             raise ValueError('execution timeout must be a zero or finite positive number.')
+        self.kernel_id = kernel_id
         self.exec_timeout = exec_timeout
         self.max_record_size = 10 * (2 ** 20)  # 10 MBytes
         self.client_features = client_features or frozenset()
@@ -899,4 +900,4 @@ def match_distro_data(data: Mapping[str, Any], distro: str) -> Tuple[str, Any]:
             if distro_key == distro:
                 return (distro_key, value)
         return match_list[0]  # fallback to the latest of its kind
-    raise RuntimeError('no match found', distro)
+    raise UnsupportedBaseDistroError(distro)
