@@ -26,6 +26,7 @@ from typing import (
 )
 from uuid import UUID
 
+import aiomonitor
 import aiotools
 from aiotools import aclosing
 from callosum.rpc import Peer, RPCMessage
@@ -53,10 +54,7 @@ from .agent import AbstractAgent
 from .config import (
     agent_local_config_iv,
     agent_etcd_config_iv,
-    k8s_extra_config_iv,
     docker_extra_config_iv,
-    registry_local_config_iv,
-    registry_ecr_config_iv,
     container_etcd_config_iv,
 )
 from .exception import ResourceError
@@ -236,13 +234,13 @@ class AgentRPCServer(aobject):
     async def read_agent_config(self):
         # Fill up Redis configs from etcd.
         self.local_config['redis'] = config.redis_config_iv.check(
-            await self.etcd.get_prefix('config/redis')
+            await self.etcd.get_prefix('config/redis'),
         )
         log.info('configured redis_addr: {0}', self.local_config['redis']['addr'])
 
         # Fill up vfolder configs from etcd.
         self.local_config['vfolder'] = config.vfolder_config_iv.check(
-            await self.etcd.get_prefix('volumes')
+            await self.etcd.get_prefix('volumes'),
         )
         if self.local_config['vfolder']['mount'] is None:
             log.info('assuming use of storage-proxy since vfolder mount path is not configured in etcd')
@@ -252,7 +250,7 @@ class AgentRPCServer(aobject):
 
         # Fill up shared agent configurations from etcd.
         agent_etcd_config = agent_etcd_config_iv.check(
-            await self.etcd.get_prefix('config/agent')
+            await self.etcd.get_prefix('config/agent'),
         )
         for k, v in agent_etcd_config.items():
             self.local_config['agent'][k] = v
@@ -261,7 +259,7 @@ class AgentRPCServer(aobject):
         # Fill up global container configurations from etcd.
         try:
             container_etcd_config = container_etcd_config_iv.check(
-                await self.etcd.get_prefix('config/container')
+                await self.etcd.get_prefix('config/container'),
             )
         except TrafaretDataError as etrafa:
             log.warning("etcd: container-config error: {}".format(etrafa))
@@ -436,7 +434,7 @@ class AgentRPCServer(aobject):
             code,
             opts=opts,
             api_version=api_version,
-            flush_timeout=flush_timeout
+            flush_timeout=flush_timeout,
         )
         return result
 
@@ -447,7 +445,7 @@ class AgentRPCServer(aobject):
         kernel_id,          # type: str
         startup_command,    # type: str
     ) -> None:
-        # TODO: use task-group to keep track of completion/cancellation
+        # DEPRECATED
         asyncio.create_task(self.agent.execute_batch(
             KernelId(UUID(kernel_id)),
             startup_command,
@@ -460,7 +458,7 @@ class AgentRPCServer(aobject):
         self,
         kernel_id,   # type: str
         service,     # type: str
-        opts         # type: Dict[str, Any]
+        opts,        # type: Dict[str, Any]
     ):
         # type: (...) -> Dict[str, Any]
         log.info('rpc::start_service(k:{0}, app:{1})', kernel_id, service)
@@ -604,13 +602,19 @@ async def server_main(
             await identity.get_instance_ip(subnet_hint),
             rpc_addr.port,
         )
-    if not local_config['container']['kernel-host']:
-        log.debug('auto-detecting kernel host')
-        local_config['container']['kernel-host'] = await get_subnet_ip(
-            etcd, 'container', local_config['agent']['rpc-listen-addr'].host
+    if 'kernel-host' in local_config['container']:
+        log.warning("The configuration parameter `container.kernel-host` is deprecated; "
+                    "use `container.bind-host` instead!")
+        # fallback for legacy configs
+        local_config['container']['bind-host'] = local_config['container']['kernel-host']
+    if not local_config['container']['bind-host']:
+        log.debug("auto-detecting `container.bind-host` from container subnet config "
+                  "and agent.rpc-listen-addr")
+        local_config['container']['bind-host'] = await get_subnet_ip(
+            etcd, 'container', fallback_addr=local_config['agent']['rpc-listen-addr'].host,
         )
     log.info('Agent external IP: {}', local_config['agent']['rpc-listen-addr'].host)
-    log.info('Container external IP: {}', local_config['container']['kernel-host'])
+    log.info('Container external IP: {}', local_config['container']['bind-host'])
     if not local_config['agent']['region']:
         local_config['agent']['region'] = await identity.get_instance_region()
     log.info('Node ID: {0} (machine-type: {1}, host: {2})',
@@ -621,6 +625,16 @@ async def server_main(
     # Pre-load compute plugin configurations.
     local_config['plugins'] = await etcd.get_prefix_dict('config/plugins/accelerator')
 
+    # Start aiomonitor.
+    # Port is set by config (default=50002).
+    monitor = aiomonitor.Monitor(
+        loop,
+        port=local_config['agent']['aiomonitor-port'],
+        console_enabled=False,
+    )
+    monitor.prompt = "monitor (agent) >>> "
+    monitor.start()
+
     # Start RPC server.
     global agent_instance
     agent = await AgentRPCServer.new(
@@ -630,9 +644,12 @@ async def server_main(
     agent_instance = agent
 
     # Run!
-    async with agent:
-        stop_signal = yield
-        agent.mark_stop_signal(stop_signal)
+    try:
+        async with agent:
+            stop_signal = yield
+            agent.mark_stop_signal(stop_signal)
+    finally:
+        monitor.close()
 
 
 @click.group(invoke_without_command=True)
@@ -663,8 +680,8 @@ def main(
     config.override_with_env(raw_cfg, ('agent', 'pid-file'), 'BACKEND_PID_FILE')
     config.override_with_env(raw_cfg, ('container', 'port-range'),
                              'BACKEND_CONTAINER_PORT_RANGE')
-    config.override_with_env(raw_cfg, ('container', 'kernel-host'),
-                             'BACKEND_KERNEL_HOST_OVERRIDE')
+    config.override_with_env(raw_cfg, ('container', 'bind-host'),
+                             'BACKEND_BIND_HOST_OVERRIDE')
     config.override_with_env(raw_cfg, ('container', 'sandbox-type'), 'BACKEND_SANDBOX_TYPE')
     config.override_with_env(raw_cfg, ('container', 'scratch-root'), 'BACKEND_SCRATCH_ROOT')
     if debug:
@@ -677,18 +694,10 @@ def main(
     try:
         cfg = config.check(raw_cfg, agent_local_config_iv)
         if cfg['agent']['backend'] == AgentBackend.KUBERNETES:
-            cfg = config.check(raw_cfg, k8s_extra_config_iv)
-            if cfg['registry']['type'] == 'local':
-                registry_target_config_iv = registry_local_config_iv
-            elif cfg['registry']['type'] == 'ecr':
-                registry_target_config_iv = registry_ecr_config_iv
-            else:
-                print('Validation of agent configuration has failed: registry type {} not supported'
-                    .format(cfg['registry']['type']), file=sys.stderr)
-                raise click.Abort()
-
-            registry_cfg = config.check(cfg['registry'], registry_target_config_iv)
-            cfg['registry'] = registry_cfg
+            if cfg['container']['scratch-type'] == 'k8s-nfs' and \
+                    (cfg['container']['scratch-nfs-address'] is None
+                        or cfg['container']['scratch-nfs-options'] is None):
+                raise ValueError('scratch-nfs-address and scratch-nfs-options are required for k8s-nfs')
         if cfg['agent']['backend'] == AgentBackend.DOCKER:
             config.check(raw_cfg, docker_extra_config_iv)
         if 'debug' in cfg and cfg['debug']['enabled']:
