@@ -6,6 +6,7 @@ import ipaddress
 import json
 import logging
 from pathlib import Path
+import platform
 import re
 from typing import (
     Any,
@@ -16,7 +17,6 @@ from typing import (
     MutableMapping,
     Optional,
     Protocol,
-    Sequence,
     Tuple,
     Type,
     TypeVar,
@@ -77,6 +77,18 @@ def generate_local_instance_id(hint: str) -> str:
     return hashlib.md5(hint.encode('utf-8')).hexdigest()[:12]
 
 
+def get_arch_name() -> str:
+    ret = platform.machine().lower()
+    aliases = {
+        "arm64": "aarch64",  # macOS with LLVM
+        "amd64": "x86_64",   # Windows/Linux
+        "x64": "x86_64",     # Windows
+        "x32": "x86",        # Windows
+        "i686": "x86",       # Windows
+    }
+    return aliases.get(ret, ret)
+
+
 def update_nested_dict(dest: MutableMapping, additions: Mapping) -> None:
     for k, v in additions.items():
         if k not in dest:
@@ -85,8 +97,8 @@ def update_nested_dict(dest: MutableMapping, additions: Mapping) -> None:
             if isinstance(dest[k], MutableMapping):
                 assert isinstance(v, MutableMapping)
                 update_nested_dict(dest[k], v)
-            elif isinstance(dest[k], Sequence):
-                assert isinstance(v, Sequence)
+            elif isinstance(dest[k], List):
+                assert isinstance(v, List)
                 dest[k].extend(v)
             else:
                 dest[k] = v
@@ -241,7 +253,7 @@ async def host_pid_to_container_pid(container_id: str, host_pid: HostPID) -> Con
                         'AttachStdout': True,
                         'AttachStderr': True,
                         'Cmd': ['ps', '-aux'],
-                    }
+                    },
                 )
                 exec_id = result['Id']
                 async with docker._query(
@@ -261,7 +273,7 @@ async def host_pid_to_container_pid(container_id: str, host_pid: HostPID) -> Con
                 procs = result[1:]
                 pid_idx, cmd_idx = head.index('PID'), head.index('COMMAND')
                 container_table = list(
-                    filter(lambda x: cmd == ' '.join(x[cmd_idx:]) if x else False, procs)
+                    filter(lambda x: cmd == ' '.join(x[cmd_idx:]) if x else False, procs),
                 )
 
                 # When there are multiple processes which have the same COMMAND, just get the index of
